
/*--------------------------------------------------------------*/
    /* #region - Product Single Image Grid */
/*--------------------------------------------------------------*/

	.wdt-product-image-gallery-holder { display: block; overflow: hidden; position: relative; }

	.wdt-product-image-gallery-container span.new { background-color: indianred; font-size: .857em; color: var(--wdtAccentTxtColor); padding: 2px 10px; position: absolute; left: auto; right: 0; top: 0; z-index: 9; }

	.wdt-product-image-gallery-container .wdt-product-image-gallery-thumb-enlarger { cursor: pointer; font-size: 0; opacity: 0; position: absolute; left: 5px; top: 5px; height: 45px; line-height: 45px; text-align: center; visibility: hidden; width: 45px; z-index: 5; -webkit-transition: var(--wdtBaseTransition); transition: var(--wdtBaseTransition); }

	.wdt-product-image-gallery-container .wdt-product-image-gallery-thumb-enlarger:before { color: var(--wdtAccentTxtColor); content: "\e802"; display: inline-block; font-family: "Advenx Icons"; font-size: 16px; height: 100%; width: 100%; }


	.wdt-product-image-gallery-container:hover .wdt-product-image-gallery-thumb-enlarger { opacity: 1; visibility: visible; -webkit-border-radius: 50%; border-radius: 50%; }

	.wdt-product-image-gallery-container .wdt-product-image-gallery-thumb-enlarger,
	.wdt-product-image-gallery-container:hover .wdt-product-image-gallery-thumb-enlarger:hover { -webkit-border-radius: 5px; border-radius: 5px; }


	/* Product Images Gallery - Grid */
	.wdt-product-image-gallery .wdt-product-image.column { margin-bottom: 2%; }
	.wdt-product-image-gallery .wdt-product-image.column.no-space { margin-bottom: 0; }

/* #endregion - Product Single Image Gallery - Grid */


/*--------------------------------------------------------------*/
    /* #region - Accents */
/*--------------------------------------------------------------*/

	/* Primary */
        .wdt-product-image-gallery-container .wdt-product-image-gallery-thumb-enlarger { background-color: rgba(var(--wdtPrimaryColorRgb),0.95) }

 /* #endregion - Accents */